@@ -5,7 +5,6 @@ TODO:
  - Replace the elements and project formats with the dream syntax
 """
 
-from __future__ import unicode_literals
 
 import argparse
 import glob
@@ -55,12 +54,18 @@ def bandplot(
     mode="rgb",
     normalise="all",
     interpolate_factor=4,
+    color1="#FF0000",
+    color2="#00FF00",
+    color3="#0000FF",
+    colorspace="lab",
     circle_size=150,
     dos_file=None,
     cart_coords=False,
     scissor=None,
     ylabel="Energy (eV)",
     dos_label=None,
+    zero_line=False,
+    zero_energy=None,
     elements=None,
     lm_orbitals=None,
     atoms=None,
@@ -160,6 +165,15 @@ def bandplot(
                    selected projections.
               * ``None``: No normalisation performed.
 
+        color1 (str): A color specified in any way supported by matplotlib. Used
+            when ``mode = 'rgb'``.
+        color2 (str): A color specified in any way supported by matplotlib. Used
+            when ``mode = 'rgb'``.
+        color3 (str): A color specified in any way supported by matplotlib. Used
+            when ``mode = 'rgb'``.
+        colorspace (str): The colorspace in which to perform the interpolation. The
+            allowed values are rgb, hsv, lab, luvlc, lablch, and xyz. Used
+            when ``mode = 'rgb'``.
         circle_size (:obj:`float`, optional): The area of the circles used
             when ``mode = 'stacked'``.
         cart_coords (:obj:`bool`, optional): Whether the k-points are read as
@@ -168,9 +182,14 @@ def bandplot(
             ``False`` (fractional coordinates).
         scissor (:obj:`float`, optional): Apply a scissor operator (rigid shift
             of the CBM), use with caution if applying to metals.
-        dos_file (:obj:'str', optional): Path to vasprun.xml file from which to
+        dos_file (:obj:`str`, optional): Path to vasprun.xml file from which to
             read the density of states information. If set, the density of
             states will be plotted alongside the bandstructure.
+        zero_line (:obj:`bool`, optional): If true, draw a horizontal line at
+            zero energy. (To adjust where zero energy sits, use zero_energy.)
+        zero_energy (:obj:`float`, optional): Energy offset determining position
+            of zero energy. By default, this is the VBM. It may be useful to
+            set this to e.g. a calculated self-consistent Fermi energy.
         elements (:obj:`dict`, optional): The elements and orbitals to extract
             from the projected density of states. Should be provided as a
             :obj:`dict` with the keys as the element names and corresponding
@@ -278,9 +297,9 @@ def bandplot(
         for bands_file in filenames:
             cell_file = _replace_ext(bands_file, "cell")
             if os.path.isfile(cell_file):
-                logging.info("Found cell file {}...".format(cell_file))
+                logging.info(f"Found cell file {cell_file}...")
             else:
-                logging.info("Did not find cell file {}...".format(cell_file))
+                logging.info(f"Did not find cell file {cell_file}...")
                 cell_file = None
             bs = castep_band_structure(bands_file, cell_file=cell_file)
             bandstructures.append(bs)
@@ -290,7 +309,7 @@ def bandplot(
         ext = bnds_file.split(".")[-1]
         bnds_folder = os.path.join(bnds_file, os.path.pardir)
 
-        site_file = os.path.abspath(os.path.join(bnds_folder, "site.{}".format(ext)))
+        site_file = os.path.abspath(os.path.join(bnds_folder, f"site.{ext}"))
 
         if os.path.isfile(site_file):
             logging.info("site file found, reading lattice...")
@@ -298,12 +317,11 @@ def bandplot(
             bnds_lattice = site_data.structure.lattice
             alat = site_data.alat
         else:
-            raise IOError(
-                "Site file {} not found: "
-                "needed to determine lattice".format(site_file)
+            raise OSError(
+                f"Site file {site_file} not found: needed to determine lattice"
             )
 
-        syml_file = os.path.abspath(os.path.join(bnds_folder, "syml.{}".format(ext)))
+        syml_file = os.path.abspath(os.path.join(bnds_folder, f"syml.{ext}"))
         if os.path.isfile(syml_file):
             logging.info("syml file found, reading special-point labels...")
             bnds_labels = labels_from_syml(syml_file)
@@ -339,15 +357,24 @@ def bandplot(
 
     # don't save if pyplot object provided
     save_files = False if plt else True
+    spin = string_to_spin(spin)  # Convert spin name to pymatgen Spin object
 
     dos_plotter = None
     dos_opts = None
     if dos_file:
         if code == "vasp":
             dos, pdos = load_dos(
-                dos_file, elements, lm_orbitals, atoms, gaussian, total_only
+                dos_file,
+                elements,
+                lm_orbitals,
+                atoms,
+                gaussian,
+                total_only,
+                scissor=scissor,
             )
         elif code == "castep":
+            if scissor:
+                raise ValueError("Scissor not compatabile with CASTEP DOS.")
             pdos_file = None
             if cell_file:
                 pdos_file = _replace_ext(cell_file, "pdos_bin")
@@ -360,9 +387,7 @@ def bandplot(
                 else:
                     logging.info(f"Found PDOS file {pdos_file}")
             else:
-                logging.info(
-                    f"Cell file {cell_file} does not exist, " "cannot plot PDOS."
-                )
+                logging.info(f"Cell file {cell_file} does not exist, cannot plot PDOS.")
 
             dos, pdos = read_castep_dos(
                 dos_file,
@@ -385,7 +410,6 @@ def bandplot(
     if scissor:
         bs = bs.apply_scissor(scissor)
 
-    spin = string_to_spin(spin)  # Convert spin name to pymatgen Spin object
     plotter = SBSPlotter(bs)
     if projection_selection:
         plt = plotter.get_projected_plot(
@@ -393,8 +417,14 @@ def bandplot(
             mode=mode,
             normalise=normalise,
             interpolate_factor=interpolate_factor,
+            color1=color1,
+            color2=color2,
+            color3=color3,
+            colorspace=colorspace,
             circle_size=circle_size,
             zero_to_efermi=True,
+            zero_line=zero_line,
+            zero_energy=zero_energy,
             ymin=ymin,
             ymax=ymax,
             height=height,
@@ -413,6 +443,8 @@ def bandplot(
     else:
         plt = plotter.get_plot(
             zero_to_efermi=True,
+            zero_line=zero_line,
+            zero_energy=zero_energy,
             ymin=ymin,
             ymax=ymax,
             height=height,
@@ -430,8 +462,8 @@ def bandplot(
         )
 
     if save_files:
-        basename = "band.{}".format(image_format)
-        filename = "{}_{}".format(prefix, basename) if prefix else basename
+        basename = f"band.{image_format}"
+        filename = f"{prefix}_{basename}" if prefix else basename
         if directory:
             filename = os.path.join(directory, filename)
         plt.savefig(filename, format=image_format, dpi=dpi, bbox_inches="tight")
@@ -468,7 +500,7 @@ def find_vasprun_files():
         elif os.path.exists(vr_file_gz):
             filenames.append(vr_file_gz)
         else:
-            logging.error("ERROR: No vasprun.xml found in {}!".format(fol))
+            logging.error(f"ERROR: No vasprun.xml found in {fol}!")
             sys.exit()
 
     return filenames
@@ -485,7 +517,7 @@ def save_data_files(bs, prefix=None, directory=None):
     Returns:
         The filename of the written data file.
     """
-    filename = "{}_band.dat".format(prefix) if prefix else "band.dat"
+    filename = f"{prefix}_band.dat" if prefix else "band.dat"
     directory = directory if directory else "."
     filename = os.path.join(directory, filename)
 
@@ -501,14 +533,14 @@ def save_data_files(bs, prefix=None, directory=None):
         # write the spin up eigenvalues
         for band in bs.bands[Spin.up]:
             for d, e in zip(bs.distance, band):
-                f.write("{:.8f} {:.8f}\n".format(d, e - zero))
+                f.write(f"{d:.8f} {e - zero:.8f}\n")
             f.write("\n")
 
         # calculation is spin polarised, write spin down bands at end of file
         if bs.is_spin_polarized:
             for band in bs.bands[Spin.down]:
                 for d, e in zip(bs.distance, band):
-                    f.write("{:.8f} {:.8f}\n".format(d, e - zero))
+                    f.write(f"{d:.8f} {e - zero:.8f}\n")
                 f.write("\n")
     return filename
 
@@ -559,12 +591,10 @@ def _get_parser():
         description="""
     bandplot is a script to produce publication-ready band
     structure diagrams""",
-        epilog="""
-    Author: {}
-    Version: {}
-    Last updated: {}""".format(
-            __author__, __version__, __date__
-        ),
+        epilog=f"""
+    Author: {__author__}
+    Version: {__version__}
+    Last updated: {__date__}""",
     )
 
     parser.add_argument(
@@ -609,13 +639,13 @@ def _get_parser():
         "--mode",
         default="rgb",
         type=str,
-        help=("mode for orbital projections (options: rgb, " "stacked)"),
+        help=("mode for orbital projections (options: rgb, stacked)"),
     )
     parser.add_argument(
         "--normalise",
         default="all",
         type=str,
-        help=("how to normalise projections (options: all, " "select)"),
+        help=("how to normalise projections (options: all, select)"),
     )
     parser.add_argument(
         "--interpolate-factor",
@@ -623,7 +653,7 @@ def _get_parser():
         default=4,
         dest="interpolate_factor",
         metavar="N",
-        help=("interpolate factor for band structure " "projections (default: 4)"),
+        help=("interpolate factor for band structure projections (default: 4)"),
     )
     parser.add_argument(
         "--cartesian",
@@ -633,13 +663,48 @@ def _get_parser():
         "outputs are less ambiguous and this option will "
         "be ignored if --code=vasp.",
     )
+    parser.add_argument(
+        "--colour1",
+        type=str,
+        default="#FF0000",
+        dest="color1",
+        metavar="C",
+        help="colour1 for rgb projections (default: red)",
+    )
+    parser.add_argument(
+        "--colour2",
+        type=str,
+        default="#00FF00",
+        dest="color2",
+        metavar="C",
+        help="colour2 for rgb projections (default: green)",
+    )
+    parser.add_argument(
+        "--colour3",
+        type=str,
+        default="#0000FF",
+        dest="color3",
+        metavar="C",
+        help="colour3 for rgb projections (default: blue)",
+    )
+    parser.add_argument(
+        "--colourspace",
+        type=str,
+        default="lab",
+        dest="colorspace",
+        metavar="C",
+        help=(
+            "colorspace used for interpolation of for rgb projections (options: "
+            "lab[default], rgb, hsv, luvlc, lablch, and xyz)"
+        ),
+    )
     parser.add_argument(
         "--circle-size",
         type=int,
         default=150,
         dest="circle_size",
         metavar="S",
-        help=('circle size for "stacked" projections ' "(default: 150)"),
+        help='circle size for "stacked" projections (default: 150)',
     )
     parser.add_argument(
         "--ylabel",
@@ -657,6 +722,24 @@ def _get_parser():
     parser.add_argument(
         "--dos", default=None, help="path to density of states vasprun.xml"
     )
+
+    parser.add_argument(
+        "--zero-line",
+        action="store_true",
+        dest="zero_line",
+        help="Plot horizontal line at energy zero",
+    )
+
+    parser.add_argument(
+        "--zero-energy",
+        type=float,
+        dest="zero_energy",
+        default=None,
+        help=(
+            "Reference energy: energy will be shifted to place this energy "
+            "at zero. If not specified, zero will be set to the VBM."
+        ),
+    )
     parser.add_argument(
         "--elements",
         type=_el_orb,
@@ -783,7 +866,7 @@ def main():
 
     if args.config is None:
         config_path = resource_filename(
-            Requirement.parse("sumo"), "sumo.plotting/orbital_colours.conf"
+            Requirement.parse("sumo"), "sumo/plotting/orbital_colours.conf"
         )
     else:
         config_path = args.config
@@ -806,11 +889,17 @@ def main():
         interpolate_factor=args.interpolate_factor,
         cart_coords=args.cartesian,
         scissor=args.scissor,
+        color1=args.color1,
+        color2=args.color2,
+        color3=args.color3,
+        colorspace=args.colorspace,
         circle_size=args.circle_size,
         yscale=args.scale,
         ylabel=args.ylabel,
         dos_label=args.dos_label,
         dos_file=args.dos,
+        zero_line=args.zero_line,
+        zero_energy=args.zero_energy,
         elements=args.elements,
         lm_orbitals=args.orbitals,
         atoms=args.atoms,
