@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Scanlon Materials Theory Group
 # Distributed under the terms of the MIT License.
 
@@ -9,7 +8,6 @@ TODO:
     * Add ability to scale an orbitals density of states
 """
 
-from __future__ import unicode_literals
 
 import argparse
 import logging
@@ -65,9 +63,11 @@ def dosplot(
     xmin=-6.0,
     xmax=6.0,
     num_columns=2,
-    yscale=1,
     xlabel="Energy (eV)",
-    ylabel="Arb. units",
+    ylabel="DOS",
+    yscale=1,
+    zero_energy=None,
+    zero_line=False,
     style=None,
     no_base_style=False,
     image_format="pdf",
@@ -167,6 +167,10 @@ def dosplot(
         xlabel (:obj:`str`, optional): Label/units for x-axis (i.e. energy)
         ylabel (:obj:`str`, optional): Label/units for y-axis (i.e. DOS)
         yscale (:obj:`float`, optional): Scaling factor for the y-axis.
+        zero_line (:obj:`bool`, optional): Plot vertical line at energy zero.
+        zero_energy (:obj:`float`, optional): Zero energy reference (e.g. Fermi
+            energy from sc-fermi.) If not given, behaviour is determined by
+            boolean ``shift``.
         style (:obj:`list` or :obj:`str`, optional): (List of) matplotlib style
             specifications, to be composed on top of Sumo base style.
         no_base_style (:obj:`bool`, optional): Prevent use of sumo base style.
@@ -270,18 +274,18 @@ def dosplot(
             else:
                 raise ValueError("No questaal dos file found")
 
-        if os.path.exists("tdos.{}".format(ext)):
-            tdos_file = "tdos.{}".format(ext)
+        if os.path.exists(f"tdos.{ext}"):
+            tdos_file = f"tdos.{ext}"
         else:
             tdos_file = None
-        if os.path.exists("site.{}".format(ext)):
-            site_file = "site.{}".format(ext)
+        if os.path.exists(f"site.{ext}"):
+            site_file = f"site.{ext}"
         else:
             site_file = None
 
         if shift:
             logging.warning(
-                "Fermi level shift requested, but not implemented " "for Questaal DOS."
+                "Fermi level shift requested, but not implemented for Questaal DOS."
             )
 
         dos, pdos = sumo.io.questaal.read_dos(
@@ -297,13 +301,14 @@ def dosplot(
         )
 
     else:
-        logging.error("ERROR: Unrecognised code: {}".format(code))
+        logging.error(f"ERROR: Unrecognised code: {code}")
         return
 
     save_files = False if plt else True  # don't save if pyplot object provided
 
     spin = string_to_spin(spin)  # Convert spin name to pymatgen Spin object
     plotter = SDOSPlotter(dos, pdos)
+
     plt = plotter.get_plot(
         subplot=subplot,
         width=width,
@@ -318,6 +323,9 @@ def dosplot(
         legend_frame_on=legend_frame_on,
         xlabel=xlabel,
         ylabel=ylabel,
+        zero_line=zero_line,
+        zero_to_efermi=shift,
+        zero_energy=zero_energy,
         legend_cutoff=legend_cutoff,
         dpi=dpi,
         plt=plt,
@@ -328,8 +336,8 @@ def dosplot(
     )
 
     if save_files:
-        basename = "dos.{}".format(image_format)
-        filename = "{}_{}".format(prefix, basename) if prefix else basename
+        basename = f"dos.{image_format}"
+        filename = f"{prefix}_{basename}" if prefix else basename
         if directory:
             filename = os.path.join(directory, filename)
         plt.savefig(filename, format=image_format, dpi=dpi, bbox_inches="tight")
@@ -407,12 +415,10 @@ def _get_parser():
         description="""
     dosplot is a script to produce publication-ready density of
     states diagrams""",
-        epilog="""
-    Author: {}
-    Version: {}
-    Last updated: {}""".format(
-            __author__, __version__, __date__
-        ),
+        epilog=f"""
+    Author: {__author__}
+    Version: {__version__}
+    Last updated: {__date__}""",
     )
 
     parser.add_argument(
@@ -502,12 +508,23 @@ def _get_parser():
         dest="legend_frame",
         help="display a box around the legend",
     )
-    parser.add_argument(
+
+    shift = parser.add_mutually_exclusive_group()
+
+    shift.add_argument(
         "--no-shift",
         action="store_false",
         dest="shift",
         help="don't shift the VBM/Fermi level to 0 eV",
     )
+    shift.add_argument(
+        "--zero-energy",
+        type=float,
+        default=None,
+        dest="zero_energy",
+        help="Plot vertical line at energy zero",
+    )
+
     parser.add_argument(
         "--total-only",
         action="store_true",
@@ -553,11 +570,17 @@ def _get_parser():
         help="x-axis (i.e. energy) label/units",
     )
     parser.add_argument(
-        "--ylabel", type=str, default="Arb. units", help="y-axis (i.e. DOS) label/units"
+        "--ylabel", type=str, default="DOS", help="y-axis (i.e. DOS) label/units"
     )
     parser.add_argument(
         "--yscale", type=float, default=1, help="scaling factor for the y-axis"
     )
+    parser.add_argument(
+        "--zero-line",
+        action="store_true",
+        dest="zero_line",
+        help="Plot vertical line at energy zero",
+    )
     parser.add_argument(
         "--format",
         type=str,
@@ -598,6 +621,11 @@ def main():
     warnings.filterwarnings("ignore", category=UnicodeWarning, module="matplotlib")
     warnings.filterwarnings("ignore", category=UserWarning, module="pymatgen")
 
+    if args.zero_energy is not None:
+        shift = False
+    else:
+        shift = args.shift
+
     dosplot(
         filename=args.filename,
         code=args.code,
@@ -608,7 +636,7 @@ def main():
         atoms=args.atoms,
         spin=args.spin,
         subplot=args.subplot,
-        shift=args.shift,
+        shift=shift,
         total_only=args.total_only,
         plot_total=args.total,
         legend_on=args.legend,
@@ -626,6 +654,8 @@ def main():
         xlabel=args.xlabel,
         ylabel=args.ylabel,
         yscale=args.yscale,
+        zero_line=args.zero_line,
+        zero_energy=args.zero_energy,
         image_format=args.image_format,
         dpi=args.dpi,
         fonts=args.font,
