@@ -158,7 +158,7 @@ class SDOSPlotter:
             energy_shift = -dos.efermi if zero_to_efermi else 0.0
         elif zero_to_efermi:
             raise ValueError(
-                "Cannot use zero_energy and " "zero_to_efermi simultaneously."
+                "Cannot use zero_energy and zero_to_efermi simultaneously."
             )
         else:
             energy_shift = -zero_energy
@@ -249,7 +249,7 @@ class SDOSPlotter:
         legend_frame_on=False,
         legend_cutoff=3,
         xlabel="Energy (eV)",
-        ylabel="Arb. units",
+        ylabel="DOS",
         zero_to_efermi=True,
         zero_line=False,
         zero_energy=None,
